========
User API
========

Base Models
===========

.. autoclass:: ravenpy.models.base.Raven
   :members:
   :noindex:

.. autoclass:: ravenpy.models.base.Ostrich
   :members:
   :noindex:

.. autoclass:: ravenpy.models.multimodel.RavenMultiModel
   :members:
   :noindex:

Emulators
=========

.. automodule::  ravenpy.models.emulators.blended
   :members:
   :noindex:

.. automodule::  ravenpy.models.emulators.gr4jcn
   :members:
   :noindex:

.. automodule::  ravenpy.models.emulators.hbvec
   :members:
   :noindex:

.. automodule::  ravenpy.models.emulators.hmets
   :members:
   :noindex:

.. automodule::  ravenpy.models.emulators.mohyse
   :members:
   :noindex:

Configuration
=============

.. automodule::  ravenpy.config.commands
   :members:
   :noindex:

.. automodule::  ravenpy.config.rvs
   :members:
   :noindex:

Extractors
==========

.. automodule::  ravenpy.extractors.routing_product
   :members:
   :noindex:

Utilities
=========

Geospatial
----------
.. automodule::  ravenpy.utilities.io
   :members:
   :noindex:

.. automodule::  ravenpy.utilities.geo
   :members:
   :noindex:

.. automodule::  ravenpy.utilities.geoserver
   :members:
   :noindex:

Graphics
--------
.. automodule::  ravenpy.utilities.graphs
   :members:
   :noindex:

Regionalization
---------------

.. automodule::  ravenpy.utilities.regionalization
   :members:
   :noindex:
